@@ -1,5 +1,5 @@
 # vi:fdm=marker fdl=0
-# $Id: Mean.pm,v 1.14 2003/12/09 01:58:09 jettero Exp $ 
+# $Id: Mean.pm,v 1.15 2004/01/29 16:17:20 jettero Exp $ 
 
 package Statistics::Basic::Mean;
 
@@ -124,6 +124,15 @@ __END__
 
     A machine to calculate the mean of a given vector.
 
+=head1 ENV VARIABLES
+
+=head2 DEBUG
+
+   Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
+
+   Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
+   enable debugging dynamically.
+
 =head1 AUTHOR
 
     Please contact me with ANY suggestions, no matter how pedantic.
